.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install umongo

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv umongo
    $ pip install umongo
